
-----------------------------------------------------------------------------------------------------------------------------
-- Aktivierung des Protokollmodus fr das Fibu-/OPos-Modul einer ProFI-Datenbank (Version 13.020)
-- Das Skript muss in db_inst ausgefhrt werden.
--
-- 27.03.2012 (ve): Einheitliche Funktion zum Lschen der Trigger.
-- 26.03.2012 (ve): Die Trigger fr SQL-Server sind mit der Klausel SET NOCOUNT ON versehen.
-- 16.03.2012 (ve): Spalte dec_kreditlimit aus der Tabelle fibu_konto entfernt.
-- 8.vii.2008 (ws): Erweiterungen an fibu_konto
-- 20.xii.2007(ws): nun auch fr eEvolution
-- 18.viii.2006(ws): eigenes Skript fr die Trigger
-- 14.vii.2006(ws): Fibu_Aufbau wird auch noch mitprotokolliert
-- 6.xii.2006(ws): Bank-Protokolltrigger fr SQL Server korrigiert
-- 28.vii.2005(ws): nderungen an der Bank-Tabelle werden mitprotokolliert
-- 12.i.2004(ws): Tabellen fibu_belegkopf und fibu_belegzeile werden auch mitprotokolliert
-- 3.xii.2003(ws): Updates auf fibu.konto.si_maxmahnung werden nicht mehr mitprotokolliert
-- 8.x.2003(ws): das Skript ist alphabetisch nach Tabellennamen sortiert
-- 29.viii.2003(ws): Trigger auf fibu_konto reagiert auf Buchungs-Updates nicht mehr
-----------------------------------------------------------------------------------------------------------------------------


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_aufbau
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_aufbau', 'fibu_aufbau' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_aufbau', 'fibu_aufbau', 'fibu_pt_aufbau', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_aufbau', 'fibu_aufbau', 'fibu_pt_aufbau', 'D' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_aufbau', 'fibu_aufbau', 'fibu_pt_aufbau', 'I' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_auswertungskreis_benutzer
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_auswertkreis_benutzer', 'FIBU_AUSWERTUNGSKREIS_BENUTZER' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_auswertkreis_benutzer', 'fibu_auswertungskreis_benutzer', 'fibu_pt_auswertkreis_benutzer', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_auswertkreis_benutzer', 'fibu_auswertungskreis_benutzer', 'fibu_pt_auswertkreis_benutzer', 'I' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_auswertkreis_benutzer', 'fibu_auswertungskreis_benutzer', 'fibu_pt_auswertkreis_benutzer', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_auswertungskreis_mitglied
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_auswertkreis_mitglied', 'fibu_auswertungskreis_mitglied' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_auswertkreis_mitglied', 'fibu_auswertungskreis_mitglied', 'fibu_pt_auswertkreis_mitglied', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_auswertkreis_mitglied', 'fibu_auswertungskreis_mitglied', 'fibu_pt_auswertkreis_mitglied', 'I' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_auswertkreis_mitglied', 'fibu_auswertungskreis_mitglied', 'fibu_pt_auswertkreis_mitglied', 'D' )

-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_auswertungskreis
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_auswertungskreis', 'fibu_auswertungskreis' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_auswertungskreis', 'fibu_auswertungskreis', 'fibu_pt_auswertungskreis', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_auswertungskreis', 'fibu_auswertungskreis', 'fibu_pt_auswertungskreis', 'I' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_auswertungskreis', 'fibu_auswertungskreis', 'fibu_pt_auswertungskreis', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_bank: fibu_bank.c_inhaber_abi-Spalte ist nur vorhanden, wenn ABI tatschlich auch installiert ist
-- Bei eEvolution werden nderungen an bank protokolliert, also auch solche vom z. b. KuLiMi
-----------------------------------------------------------------------------------------------------------------------------
#IF Oracle
	SELECT	CASE WHEN cc=0 THEN '''<N. N.>''' ELSE ':NEW.c_inhaber_abi' END,
		CASE WHEN cc=0 THEN '''<N. N.>''' ELSE ':OLD.c_inhaber_abi' END
	FROM (
		SELECT COUNT(*) cc
		FROM fibu_systemdatum
		WHERE c_parameter='ABI-Version'
	     )
	INTO :saInternalObjectName[1], :saInternalObjectName[2]
	/
	CREATE OR REPLACE TRIGGER fibu_tp_bank
	AFTER UPDATE OR DELETE OR INSERT ON fibu_bank
	FOR EACH ROW
	DECLARE
		aktion CHAR(1);
	BEGIN
		IF inserting THEN
			INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
				c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi,
				c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
				c_text2, c_text3, c_text4, c_text5, i_bank_refid,
				i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
				i_refnr, si_clearingart, c_manipulator, dt_manipulation,
				si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
			VALUES (USER, 'I', SYSDATE, 
				:NEW.c_bank, :NEW.c_blz, :NEW.c_iban, :NEW.c_inhaber, {InternalObjectName1},
				:NEW.c_kontonr, :NEW.c_land, :NEW.c_pfad, :NEW.c_swift_code, :NEW.c_text1,
				:NEW.c_text2, :NEW.c_text3, :NEW.c_text4, :NEW.c_text5, :NEW.i_bank_refid,
				:NEW.i_firm_refid, :NEW.i_flags, :NEW.i_konto, :NEW.i_kunde_refid, :NEW.i_lief_refid,
				:NEW.i_refnr, :NEW.si_clearingart, :NEW.c_manipulator, :NEW.dt_manipulation,
				:NEW.si_status, :NEW.c_validator, :NEW.dt_validation, :NEW.c_validattext, :NEW.i_ext_provider);
		ELSE
			IF deleting THEN
				aktion := 'D';
			ELSIF updating THEN
				aktion := 'U';
			ELSE
				aktion := 'x';
			END IF;
			INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
				c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi,
				c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
				c_text2, c_text3, c_text4, c_text5, i_bank_refid,
				i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
				i_refnr, si_clearingart, c_manipulator, dt_manipulation,
				si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
			VALUES (USER, aktion, SYSDATE, 
				:OLD.c_bank, :OLD.c_blz, :OLD.c_iban, :OLD.c_inhaber, {InternalObjectName2}, :OLD.c_kontonr, :OLD.c_land,
				:OLD.c_pfad, :OLD.c_swift_code, :OLD.c_text1, :OLD.c_text2, :OLD.c_text3, :OLD.c_text4, :OLD.c_text5,
				:OLD.i_bank_refid, :OLD.i_firm_refid, :OLD.i_flags, :OLD.i_konto, :OLD.i_kunde_refid, :OLD.i_lief_refid, :OLD.i_refnr,
				:OLD.si_clearingart, :OLD.c_manipulator, :OLD.dt_manipulation,
				:OLD.si_status, :OLD.c_validator, :OLD.dt_validation, :OLD.c_validattext, :OLD.i_ext_provider);
		END IF;
	END TRIGGER;
	/
#ELSIF SQLServer
	SELECT CASE WHEN COUNT(*)=0 THEN '''<N. N.>''' ELSE 'c_inhaber_abi' END
	FROM fibu_systemdatum
	WHERE c_parameter='ABI-Version'
	INTO :sInternalObjectName
	/
	#WHEN eEvolution
	IF EXISTS(SELECT 1 FROM sysobjects WHERE name='fibu_tp_bank' AND type='TR' AND uid=User_ID() AND parent_obj=Object_ID(N'bank','U'))
		DROP TRIGGER fibu_tp_bank
	/
	CREATE TRIGGER fibu_tp_bank
	ON bank AFTER DELETE, UPDATE, INSERT
	AS
	SET NOCOUNT ON
	IF EXISTS (SELECT TOP 1 * FROM deleted) BEGIN
		DECLARE @aktion CHAR(1)
		IF EXISTS (SELECT TOP 1 * FROM inserted)
			SELECT @aktion = 'U'
		ELSE
			SELECT @aktion = 'D'
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, 
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1, 
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		SELECT USER, @aktion, CURRENT_TIMESTAMP,
			c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName},
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1, 
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, 
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider
		FROM deleted
	END ELSE
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi,
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
			c_text2, c_text3, c_text4, c_text5, i_bank_refid,
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		SELECT USER, 'I', CURRENT_TIMESTAMP,
			c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName},
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider
		FROM inserted
	/
	#OTHERS
	IF EXISTS(SELECT 1 FROM sysobjects WHERE name='fibu_tp_bank' AND type='TR' AND uid=User_ID() AND parent_obj=Object_ID(N'fibu_bank','U'))
		DROP TRIGGER fibu_tp_bank
	/
	CREATE TRIGGER fibu_tp_bank
	ON fibu_bank AFTER DELETE, UPDATE, INSERT
	AS
	SET NOCOUNT ON
	IF EXISTS (SELECT TOP 1 * FROM deleted) BEGIN
		DECLARE @aktion CHAR(1)
		IF EXISTS (SELECT TOP 1 * FROM inserted)
			SELECT @aktion = 'U'
		ELSE
			SELECT @aktion = 'D'
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, 
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1, 
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		SELECT USER, @aktion, CURRENT_TIMESTAMP,
			c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName},
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1, 
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, 
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider
		FROM deleted
	END ELSE
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi,
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
			c_text2, c_text3, c_text4, c_text5, i_bank_refid,
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		SELECT USER, 'I', CURRENT_TIMESTAMP,
			c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName},
			c_kontonr, c_land, c_pfad, c_swift_code, c_text1,
			c_text2, c_text3, c_text4, c_text5, i_bank_refid, 
			i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid,
			i_refnr, si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider
		FROM inserted
	/
	#OFF
#ELSIF SQLBase
	#WHILE	SELECT name INTO :sInternalObjectName 
		FROM sysadm.systriggers
		WHERE creator=USER AND name IN('FIBU_TI_BANK','FIBU_TU_BANK','FIBU_TD_BANK')
			AND tbsnum=(SELECT snum FROM sysadm.systables WHERE name='FIBU_BANK' AND creator=USER)
	#LOOP
		DROP TRIGGER {InternalObjectName}
		/
	#ENDLOOP
	SELECT	@IF(COUNT(*), 'c_inhaber_abi', '''<N. N.>'''),
		@IF(COUNT(*), 'old.c_inhaber_abi', '''<N. N.>''')
	FROM fibu_systemdatum
	WHERE c_parameter='ABI-Version'
	INTO :saInternalObjectName[1], :saInternalObjectName[2]
	/
	CREATE TRIGGER fibu_td_bank
	AFTER DELETE ON fibu_bank
	(EXECUTE INLINE(c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName1}, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
	PROCEDURE delproc STATIC
	PARAMETERS
		STRING: c_bank
		STRING: c_blz
		STRING: c_iban
		STRING: c_inhaber
		STRING: c_inhaber_abi
		STRING: c_kontonr
		STRING: c_land
		STRING: c_pfad
		STRING: c_swift_code
		STRING: c_text1
		STRING: c_text2
		STRING: c_text3
		STRING: c_text4
		STRING: c_text5
		NUMBER: i_bank_refid
		NUMBER: i_firm_refid
		NUMBER: i_flags
		NUMBER: i_konto
		NUMBER: i_kunde_refid
		NUMBER: i_lief_refid
		NUMBER: i_refnr
		NUMBER: si_clearingart
		STRING: c_manipulator
		DATE/TIME: dt_manipulation
		NUMBER: si_status
		STRING: c_validator
		DATE/TIME: dt_validation
		STRING: c_validattext
		NUMBER: i_ext_provider
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, \'D\', SYSDATETIME,
			:c_bank, :c_blz, :c_iban, :c_inhaber, :c_inhaber_abi, :c_kontonr, :c_land,
			:c_pfad, :c_swift_code, :c_text1, :c_text2, :c_text3, :c_text4, :c_text5,
			:i_bank_refid, :i_firm_refid, :i_flags, :i_konto, :i_kunde_refid, :i_lief_refid, :i_refnr,
			:si_clearingart, :c_manipulator, :dt_manipulation,
			:si_status, :c_validator, :dt_validation, :c_validattext, :i_ext_provider)')
	)
	FOR EACH ROW
	/
	CREATE TRIGGER fibu_ti_bank
	AFTER INSERT ON fibu_bank
	(EXECUTE INLINE(c_bank, c_blz, c_iban, c_inhaber, {InternalObjectName1}, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
	PROCEDURE insproc STATIC
	PARAMETERS
		STRING: c_bank
		STRING: c_blz
		STRING: c_iban
		STRING: c_inhaber
		STRING: c_inhaber_abi
		STRING: c_kontonr
		STRING: c_land
		STRING: c_pfad
		STRING: c_swift_code
		STRING: c_text1
		STRING: c_text2
		STRING: c_text3
		STRING: c_text4
		STRING: c_text5
		NUMBER: i_bank_refid
		NUMBER: i_firm_refid
		NUMBER: i_flags
		NUMBER: i_konto
		NUMBER: i_kunde_refid
		NUMBER: i_lief_refid
		NUMBER: i_refnr
		NUMBER: si_clearingart
		STRING: c_manipulator
		DATE/TIME: dt_manipulation
		NUMBER: si_status
		STRING: c_validator
		DATE/TIME: dt_validation
		STRING: c_validattext
		NUMBER: i_ext_provider
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, \'I\', SYSDATETIME,
			:c_bank, :c_blz, :c_iban, :c_inhaber, :c_inhaber_abi, :c_kontonr, :c_land,
			:c_pfad, :c_swift_code, :c_text1, :c_text2, :c_text3, :c_text4, :c_text5,
			:i_bank_refid, :i_firm_refid, :i_flags, :i_konto, :i_kunde_refid, :i_lief_refid, :i_refnr,
			:si_clearingart, :c_manipulator, :dt_manipulation,
			:si_status, :c_validator, :dt_validation, :c_validattext, :i_ext_provider)')
	)
	FOR EACH ROW
	/
	CREATE TRIGGER fibu_tu_bank
	AFTER UPDATE ON fibu_bank
	REFERENCING OLD AS old
	(EXECUTE INLINE(old.c_bank, old.c_blz, old.c_iban, old.c_inhaber, {InternalObjectName2}, old.c_kontonr, old.c_land,
		old.c_pfad, old.c_swift_code, old.c_text1, old.c_text2, old.c_text3, old.c_text4, old.c_text5,
		old.i_bank_refid, old.i_firm_refid, old.i_flags, old.i_konto, old.i_kunde_refid, old.i_lief_refid, old.i_refnr,
		old.si_clearingart, old.c_manipulator, old.dt_manipulation,
		old.si_status, old.c_validator, old.dt_validation, old.c_validattext, old.i_ext_provider)
	PROCEDURE updproc STATIC
	PARAMETERS
		STRING: c_bank
		STRING: c_blz
		STRING: c_iban
		STRING: c_inhaber
		STRING: c_inhaber_abi
		STRING: c_kontonr
		STRING: c_land
		STRING: c_pfad
		STRING: c_swift_code
		STRING: c_text1
		STRING: c_text2
		STRING: c_text3
		STRING: c_text4
		STRING: c_text5
		NUMBER: i_bank_refid
		NUMBER: i_firm_refid
		NUMBER: i_flags
		NUMBER: i_konto
		NUMBER: i_kunde_refid
		NUMBER: i_lief_refid
		NUMBER: i_refnr
		NUMBER: si_clearingart
		STRING: c_manipulator
		DATE/TIME: dt_manipulation
		NUMBER: si_status
		STRING: c_validator
		DATE/TIME: dt_validation
		STRING: c_validattext
		NUMBER: i_ext_provider
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, \'U\', SYSDATETIME,
			:c_bank, :c_blz, :c_iban, :c_inhaber, :c_inhaber_abi, :c_kontonr, :c_land,
			:c_pfad, :c_swift_code, :c_text1, :c_text2, :c_text3, :c_text4, :c_text5,
			:i_bank_refid, :i_firm_refid, :i_flags, :i_konto, :i_kunde_refid, :i_lief_refid, :i_refnr,
			:si_clearingart, :c_manipulator, :dt_manipulation,
			:si_status, :c_validator, :dt_validation, :c_validattext, :i_ext_provider)')
	)
	FOR EACH ROW
	/
#ELSE IF INFORMIX11
	#WHILE	SELECT trigname INTO :sInternalObjectName
		FROM informix.systriggers
		WHERE owner=USER AND trigname MATCHES 'fibu_t[iud]_bank'
			AND tabid=(SELECT tabid FROM informix.systables WHERE owner=USER AND tabname='fibu_bank')
	#LOOP
		DROP TRIGGER {InternalObjectName}
		/
	#ENDLOOP
	SELECT	CASE WHEN COUNT(*)=0 THEN '''<N. N.>''' ELSE 'neu.c_inhaber_abi' END,
		CASE WHEN COUNT(*)=0 THEN '''<N. N.>''' ELSE 'alt.c_inhaber_abi' END
	FROM fibu_systemdatum
	WHERE c_parameter='ABI-Version'
	INTO :saInternalObjectName[11], :saInternalObjectName[12]
	/
	CREATE TRIGGER fibu_ti_bank
	INSERT ON fibu_bank
	REFERENCING NEW AS neu
	FOR EACH ROW (
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, 'I', CURRENT,
			neu.c_bank, neu.c_blz, neu.c_iban, neu.c_inhaber, {InternalObjectname11}, neu.c_kontonr, neu.c_land,
			neu.c_pfad, neu.c_swift_code, neu.c_text1, neu.c_text2, neu.c_text3, neu.c_text4, neu.c_text5,
			neu.i_bank_refid, neu.i_firm_refid, neu.i_flags, neu.i_konto, neu.i_kunde_refid, neu.i_lief_refid, neu.i_refnr,
			neu.si_clearingart, neu.c_manipulator, neu.dt_manipulation,
			neu.si_status, neu.c_validator, neu.dt_validation, neu.c_validattext, neu.i_ext_provider)
	);
	/
	CREATE TRIGGER fibu_td_bank
	DELETE ON fibu_bank
	REFERENCING OLD AS alt
	FOR EACH ROW(
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, 'D', CURRENT,
			alt.c_bank, alt.c_blz, alt.c_iban, alt.c_inhaber, {InternalObjectname12}, alt.c_kontonr, alt.c_land,
			alt.c_pfad, alt.c_swift_code, alt.c_text1, alt.c_text2, alt.c_text3, alt.c_text4, alt.c_text5,
			alt.i_bank_refid, alt.i_firm_refid, alt.i_flags, alt.i_konto, alt.i_kunde_refid, alt.i_lief_refid, alt.i_refnr,
			alt.si_clearingart, alt.c_manipulator, alt.dt_manipulation,
			alt.si_status, alt.c_validator, alt.dt_validation, alt.c_validattext, alt.i_ext_provider)
	);
	/
	CREATE TRIGGER fibu_tu_bank
	UPDATE ON fibu_bank
	REFERENCING OLD AS alt
	FOR EACH ROW(
		INSERT INTO fibu_pt_bank(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_bank, c_blz, c_iban, c_inhaber, c_inhaber_abi, c_kontonr, c_land,
			c_pfad, c_swift_code, c_text1, c_text2, c_text3, c_text4, c_text5,
			i_bank_refid, i_firm_refid, i_flags, i_konto, i_kunde_refid, i_lief_refid, i_refnr,
			si_clearingart, c_manipulator, dt_manipulation,
			si_status, c_validator, dt_validation, c_validattext, i_ext_provider)
		VALUES(USER, 'U', CURRENT,
			alt.c_bank, alt.c_blz, alt.c_iban, alt.c_inhaber, {InternalObjectname12}, alt.c_kontonr, alt.c_land,
			alt.c_pfad, alt.c_swift_code, alt.c_text1, alt.c_text2, alt.c_text3, alt.c_text4, alt.c_text5,
			alt.i_bank_refid, alt.i_firm_refid, alt.i_flags, alt.i_konto, alt.i_kunde_refid, alt.i_lief_refid, alt.i_refnr,
			alt.si_clearingart, alt.c_manipulator, alt.dt_manipulation,
			alt.si_status, alt.c_validator, alt.dt_validation, alt.c_validattext, alt.i_ext_provider)
	);
	/
#ENDIF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_belegkopf
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_belegkopf', 'fibu_belegkopf' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_belegkopf', 'fibu_belegkopf', 'fibu_pt_belegkopf', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_belegkopf', 'fibu_belegkopf', 'fibu_pt_belegkopf', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_belegzeile
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_belegzeile', 'fibu_belegzeile' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_belegzeile', 'fibu_belegzeile', 'fibu_pt_belegzeile', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_belegzeile', 'fibu_belegzeile', 'fibu_pt_belegzeile', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_bilanzaufbau
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_bilzaufbau', 'fibu_bilanzaufbau' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_bilzaufbau', 'fibu_bilanzaufbau', 'fibu_pt_bilzaufbau', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_bilzaufbau', 'fibu_bilanzaufbau', 'fibu_pt_bilzaufbau', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_buchungskreis
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_buchungskreis', 'fibu_buchungskreis' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_buchungskreis', 'fibu_buchungskreis', 'fibu_pt_buchungskreis', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_buchungskreis', 'fibu_buchungskreis', 'fibu_pt_buchungskreis', 'I' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_buchungskreis', 'fibu_buchungskreis', 'fibu_pt_buchungskreis', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_firmendaten: nur fr syska-Standalone
-----------------------------------------------------------------------------------------------------------------------------
#WHEN syska
	#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_firmdaten', 'fibu_firmendaten' )
	
	#SALCAE _ProtokollCreateTrigger( 'fibu_td_firmdaten', 'fibu_firmendaten', 'fibu_pt_firmdaten', 'D' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_tu_firmdaten', 'fibu_firmendaten', 'fibu_pt_firmdaten', 'U' )
#OFF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_firmenwerte: nur fr syska-Standalone
-----------------------------------------------------------------------------------------------------------------------------
#WHEN syska
	#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_firmwerte', 'fibu_firmenwerte' )
	
	#SALCAE _ProtokollCreateTrigger( 'fibu_td_firmwerte', 'fibu_firmenwerte', 'fibu_pt_firmwerte', 'D' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_tu_firmwerte', 'fibu_firmenwerte', 'fibu_pt_firmwerte', 'U' )

#OFF

-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_kontenkennung
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_kontkenn', 'fibu_kontenkennung' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_kontkenn', 'fibu_kontenkennung', 'fibu_pt_kontkenn', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_ti_kontkenn', 'fibu_kontenkennung', 'fibu_pt_kontkenn', 'I' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_kontkenn', 'fibu_kontenkennung', 'fibu_pt_kontkenn', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_konto
-----------------------------------------------------------------------------------------------------------------------------
#IF Oracle
	CREATE OR REPLACE TRIGGER fibu_tp_konto
	AFTER UPDATE OF c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef
		OR DELETE OR INSERT ON fibu_konto FOR EACH ROW
	DECLARE
		aktion CHAR(1);
	BEGIN
		IF inserting THEN
			INSERT INTO fibu_pt_konto(c_pt_benutzer, c_pt_aktion, dt_pt_timestamp,
				c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
				c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
				c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
				c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
				dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
				dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
				i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
				i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
				i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
				si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
				si_wawi_kennung, i_gruppe_refid, i_zessionstext,
				i_az_fordkto, i_az_verbkto,
				si_zahlungsavis, i_konto_datev, si_ustid_pruef)
			VALUES (USER, 'I', SYSDATE, 
				:NEW.c_ansprechpartner, :NEW.c_archiv, :NEW.c_creator, :NEW.c_email, :NEW.c_homepage, :NEW.c_kontoart, :NEW.c_konto_left,
				:NEW.c_kundennr, :NEW.c_landid, :NEW.c_manipulator, :NEW.c_name, :NEW.c_name2, :NEW.c_name3, :NEW.c_ort, :NEW.c_ort2, :NEW.c_plz, :NEW.c_plz2,
				:NEW.c_schablone, :NEW.c_sprache, :NEW.c_steuernr, :NEW.c_strasse, :NEW.c_strasse2, :NEW.c_suche, :NEW.c_tel, :NEW.c_telefax, :NEW.c_text1,
				:NEW.c_text2, :NEW.c_text3, :NEW.c_titel, :NEW.c_unsnr, :NEW.c_ustidnr, :NEW.c_waehrung, :NEW.c_zahlziel, :NEW.c_zusatz,
				:NEW.dec_wb_index, :NEW.dec_wert1, :NEW.dec_wert2, :NEW.dec_wert3,
				:NEW.dt_creation, :NEW.dt_manipulation, :NEW.i_adressflags, :NEW.i_afakto, :NEW.i_anzahlkto,
				:NEW.i_clearing, :NEW.i_eigene_bank, :NEW.i_firm_refid, :NEW.i_fordkto, :NEW.i_kennung, :NEW.i_koartnr, :NEW.i_konto, :NEW.i_kreddeb,
				:NEW.i_kundenid, :NEW.i_kunde_refid, :NEW.i_lieferantid, :NEW.i_lief_refid, :NEW.i_steuerart_refid, :NEW.i_verband,
				:NEW.i_verbkto, :NEW.si_bankeinzug, :NEW.si_datevauto, :NEW.si_klasse, :NEW.si_mahnung, :NEW.si_maxmahn, :NEW.si_option1,
				:NEW.si_option2, :NEW.si_option3, :NEW.si_skontierfaehig, :NEW.si_ustpos, :NEW.si_verdichtet,
				:NEW.si_wawi_kennung, :NEW.i_gruppe_refid, :NEW.i_zessionstext,
				:NEW.i_az_fordkto, :NEW.i_az_verbkto,
				:NEW.si_zahlungsavis, :NEW.i_konto_datev, :NEW.si_ustid_pruef);
		ELSE
			IF deleting THEN
				aktion := 'D';
			ELSIF updating THEN
				aktion := 'U';
			ELSE
				aktion := 'x';
			END IF;
			INSERT INTO fibu_pt_konto(c_pt_benutzer, c_pt_aktion, dt_pt_timestamp,
				c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
				c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
				c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
				c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
				dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
				dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
				i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
				i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
				i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
				si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
				si_wawi_kennung, i_gruppe_refid, i_zessionstext,
				i_az_fordkto, i_az_verbkto,
				si_zahlungsavis, i_konto_datev, si_ustid_pruef)
			VALUES (USER, aktion, SYSDATE, 
				:OLD.c_ansprechpartner, :OLD.c_archiv, :OLD.c_creator, :OLD.c_email, :OLD.c_homepage, :OLD.c_kontoart, :OLD.c_konto_left,
				:OLD.c_kundennr, :OLD.c_landid, :OLD.c_manipulator, :OLD.c_name, :OLD.c_name2, :OLD.c_name3, :OLD.c_ort, :OLD.c_ort2, :OLD.c_plz, :OLD.c_plz2,
				:OLD.c_schablone, :OLD.c_sprache, :OLD.c_steuernr, :OLD.c_strasse, :OLD.c_strasse2, :OLD.c_suche, :OLD.c_tel, :OLD.c_telefax, :OLD.c_text1,
				:OLD.c_text2, :OLD.c_text3, :OLD.c_titel, :OLD.c_unsnr, :OLD.c_ustidnr, :OLD.c_waehrung, :OLD.c_zahlziel, :OLD.c_zusatz,
				:OLD.dec_wb_index, :OLD.dec_wert1, :OLD.dec_wert2, :OLD.dec_wert3,
				:OLD.dt_creation, :OLD.dt_manipulation, :OLD.i_adressflags, :OLD.i_afakto, :OLD.i_anzahlkto,
				:OLD.i_clearing, :OLD.i_eigene_bank, :OLD.i_firm_refid, :OLD.i_fordkto, :OLD.i_kennung, :OLD.i_koartnr, :OLD.i_konto, :OLD.i_kreddeb,
				:OLD.i_kundenid, :OLD.i_kunde_refid, :OLD.i_lieferantid, :OLD.i_lief_refid, :OLD.i_steuerart_refid, :OLD.i_verband,
				:OLD.i_verbkto, :OLD.si_bankeinzug, :OLD.si_datevauto, :OLD.si_klasse, :OLD.si_mahnung, :OLD.si_maxmahn, :OLD.si_option1,
				:OLD.si_option2, :OLD.si_option3, :OLD.si_skontierfaehig, :OLD.si_ustpos, :OLD.si_verdichtet,
				:OLD.si_wawi_kennung, :OLD.i_gruppe_refid, :OLD.i_zessionstext,
				:OLD.i_az_fordkto, :OLD.i_az_verbkto,
				:OLD.si_zahlungsavis, :OLD.i_konto_datev, :OLD.si_ustid_pruef);
		END IF;
	END TRIGGER;
	/
#ELSIF SQLServer
	IF EXISTS (SELECT 1 FROM sysobjects WHERE id=Object_ID(N'fibu_tp_konto',N'TR') AND parent_obj=Object_ID(N'fibu_konto',N'U'))
		DROP TRIGGER fibu_tp_konto
	/

	IF EXISTS(SELECT 1 FROM sysobjects WHERE id=Object_ID(N'fibu_ti_konto',N'TR') AND parent_obj=Object_ID(N'fibu_konto',N'U'))
		DROP TRIGGER fibu_ti_konto
	/
	CREATE TRIGGER fibu_ti_konto
	ON fibu_konto AFTER INSERT
	AS
	SET NOCOUNT ON
	INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
		c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
		c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
		c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
		c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
		dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
		dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
		i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
		i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
		i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
		si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
		si_wawi_kennung, i_gruppe_refid, i_zessionstext,
		i_az_fordkto, i_az_verbkto,
		si_zahlungsavis, i_konto_datev, si_ustid_pruef)
	SELECT USER, 'I', CURRENT_TIMESTAMP,
		c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
		c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
		c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
		c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
		dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
		dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
		i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
		i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
		i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
		si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
		si_wawi_kennung, i_gruppe_refid, i_zessionstext,
		i_az_fordkto, i_az_verbkto,
		si_zahlungsavis, i_konto_datev, si_ustid_pruef
	FROM inserted
	/

	IF EXISTS(SELECT 1 FROM sysobjects WHERE id=Object_ID(N'fibu_tu_konto',N'TR') AND parent_obj=Object_ID(N'fibu_konto',N'U'))
		DROP TRIGGER fibu_tu_konto
	/
	CREATE TRIGGER fibu_tu_konto
	ON fibu_konto AFTER UPDATE
	AS
	SET NOCOUNT ON
	IF NOT (UPDATE(dec_sollsumme) OR UPDATE(dec_habensumme) OR UPDATE(dec_aktuellersaldo) OR UPDATE(eur_aktuellersaldo) OR UPDATE(d_lebudat) OR UPDATE(d_eroeffdat)
		/* Es handelt sich hier wahrscheinlich um eine regulre Buchung, die nur die Kontensalden aktualisiert */
		OR UPDATE(si_maxmahn)
		/* Oder um eine Aktualisierung der erreichten maximalen Mahnstufe */
		OR UPDATE(c_konto_left)
		/* Mutmalich hat hier der automatische c_konto-left-Trigger zugeschlagen */
		)
		INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		SELECT USER, 'U', CURRENT_TIMESTAMP,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef
		FROM deleted
	/

	IF EXISTS(SELECT 1 FROM sysobjects WHERE id=Object_ID(N'fibu_td_konto',N'TR') AND parent_obj=Object_ID(N'fibu_konto',N'U'))
		DROP TRIGGER fibu_td_konto
	/
	CREATE TRIGGER fibu_td_konto
	ON fibu_konto AFTER DELETE
	AS
	SET NOCOUNT ON
	INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
		c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
		c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
		c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
		c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
		dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
		dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
		i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
		i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
		i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
		si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
		si_wawi_kennung, i_gruppe_refid, i_zessionstext,
		i_az_fordkto, i_az_verbkto,
		si_zahlungsavis, i_konto_datev, si_ustid_pruef)
	SELECT USER, 'D', CURRENT_TIMESTAMP,
		c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
		c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
		c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
		c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
		dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
		dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
		i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
		i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
		i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
		si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
		si_wawi_kennung, i_gruppe_refid, i_zessionstext,
		i_az_fordkto, i_az_verbkto,
		si_zahlungsavis, i_konto_datev, si_ustid_pruef
	FROM deleted
	/

#ELSIF SQLBase
	#WHILE	SELECT name INTO :sInternalObjectName
		FROM sysadm.systriggers
		WHERE creator=USER AND name IN ('FIBU_TU_KONTO','FIBU_TD_KONTO','FIBU_TI_KONTO')
			AND tbsnum=(SELECT snum FROM sysadm.systables WHERE name='FIBU_KONTO' AND creator=USER)
	#LOOP
		DROP TRIGGER {InternalObjectName}
		/
	#ENDLOOP

	CREATE TRIGGER fibu_tu_konto
	AFTER UPDATE OF
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef
		ON fibu_konto
	REFERENCING OLD AS old
	(EXECUTE INLINE(old.c_ansprechpartner,old.c_archiv,old.c_creator,old.c_email,old.c_homepage,old.c_kontoart,old.c_konto_left,
			old.c_kundennr,old.c_landid,old.c_manipulator,old.c_name,old.c_name2,old.c_name3,old.c_ort,old.c_ort2,old.c_plz,old.c_plz2,
			old.c_schablone,old.c_sprache,old.c_steuernr,old.c_strasse,old.c_strasse2,old.c_suche,old.c_tel,old.c_telefax,old.c_text1,
			old.c_text2,old.c_text3,old.c_titel,old.c_unsnr,old.c_ustidnr,old.c_waehrung,old.c_zahlziel,old.c_zusatz,
			old.dec_wb_index,old.dec_wert1,old.dec_wert2,old.dec_wert3,
			old.dt_creation,old.dt_manipulation,old.i_adressflags,old.i_afakto,old.i_anzahlkto,
			old.i_clearing,old.i_eigene_bank,old.i_firm_refid,old.i_fordkto,old.i_kennung,old.i_koartnr,old.i_konto,old.i_kreddeb,
			old.i_kundenid,old.i_kunde_refid,old.i_lieferantid,old.i_lief_refid,old.i_steuerart_refid,old.i_verband,
			old.i_verbkto,old.si_bankeinzug,old.si_datevauto,old.si_klasse,old.si_mahnung,old.si_maxmahn,old.si_option1,
			old.si_option2,old.si_option3,old.si_skontierfaehig,old.si_ustpos,old.si_verdichtet,
			old.si_wawi_kennung, old.i_gruppe_refid, old.i_zessionstext,
			old.i_az_fordkto, old.i_az_verbkto,
			old.si_zahlungsavis, old.i_konto_datev, old.si_ustid_pruef)
	PROCEDURE updproc STATIC
	PARAMETERS
		STRING: ansprechpartner
		STRING: archiv
		STRING: creator
		STRING: email
		STRING: homepage
		STRING: kontoart
		STRING: konto_left
		STRING: kundennr
		STRING: landid
		STRING: manipulator
		STRING: name1
		STRING: name2
		STRING: name3
		STRING: ort
		STRING: ort2
		STRING: plz
		STRING: plz2
		STRING: schablone
		STRING: sprache
		STRING: steuernr
		STRING: strasse
		STRING: strasse2
		STRING: suche
		STRING: tel
		STRING: telefax
		STRING: text1
		STRING: text2
		STRING: text3
		STRING: titel
		STRING: unsnr
		STRING: ustidnr
		STRING: waehrung
		STRING: zahlziel
		STRING: zusatz
		NUMBER: wb_index
		NUMBER: wert1
		NUMBER: wert2
		NUMBER: wert3
		DATE/TIME: creation
		DATE/TIME: manipulation
		NUMBER: adressflags
		NUMBER: afakto
		NUMBER: anzahlkto
		NUMBER: clearing
		NUMBER: eigene_bank
		NUMBER: firm_refid
		NUMBER: fordkto
		NUMBER: kennung
		NUMBER: koartnr
		NUMBER: konto
		NUMBER: kreddeb
		NUMBER: kundenid
		NUMBER: kunde_refid
		NUMBER: lieferantid
		NUMBER: lief_refid
		NUMBER: steuerart_refid
		NUMBER: verband
		NUMBER: verbkto
		NUMBER: bankeinzug
		NUMBER: datevauto
		NUMBER: klasse
		NUMBER: mahnung
		NUMBER: maxmahn
		NUMBER: option1
		NUMBER: option2
		NUMBER: option3
		NUMBER: skontierfaehig
		NUMBER: ustpos
		NUMBER: verdichtet
		NUMBER: wawi_kennung
		NUMBER: gruppe_refid
		NUMBER: zessionstext
		NUMBER: az_fordkto
		NUMBER: az_verbkto
		NUMBER: zahlungsavis
		NUMBER: konto_datev
		NUMBER: ustid_pruef
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, \'U\', SYSDATETIME,
			:ansprechpartner, :archiv, :creator, :email, :homepage, :kontoart, :konto_left,
			:kundennr, :landid, :manipulator, :name1, :name2, :name3, :ort, :ort2, :plz, :plz2,
			:schablone, :sprache, :steuernr, :strasse, :strasse2, :suche, :tel, :telefax, :text1,
			:text2, :text3, :titel, :unsnr, :ustidnr, :waehrung, :zahlziel, :zusatz,
			:wb_index, :wert1, :wert2, :wert3,
			:creation, :manipulation, :adressflags, :afakto, :anzahlkto,
			:clearing, :eigene_bank, :firm_refid, :fordkto, :kennung, :koartnr, :konto, :kreddeb,
			:kundenid, :kunde_refid, :lieferantid, :lief_refid, :steuerart_refid, :verband,
			:verbkto, :bankeinzug, :datevauto, :klasse, :mahnung, :maxmahn, :option1,
			:option2, :option3, :skontierfaehig, :ustpos, :verdichtet,
			:wawi_kennung, :gruppe_refid, :zessionstext,
			:az_fordkto, :az_verbkto,
			:zahlungsavis, :konto_datev, :ustid_pruef)' )
	)
	FOR EACH ROW
	/

	CREATE TRIGGER fibu_td_konto
	AFTER DELETE ON fibu_konto
	(EXECUTE INLINE(c_ansprechpartner,c_archiv,c_creator,c_email,c_homepage,c_kontoart,c_konto_left,
			c_kundennr,c_landid,c_manipulator,c_name,c_name2,c_name3,c_ort,c_ort2,c_plz,c_plz2,
			c_schablone,c_sprache,c_steuernr,c_strasse,c_strasse2,c_suche,c_tel,c_telefax,c_text1,
			c_text2,c_text3,c_titel,c_unsnr,c_ustidnr,c_waehrung,c_zahlziel,c_zusatz,
			dec_wb_index,dec_wert1,dec_wert2,dec_wert3,
			dt_creation,dt_manipulation,i_adressflags,i_afakto,i_anzahlkto,
			i_clearing,i_eigene_bank,i_firm_refid,i_fordkto,i_kennung,i_koartnr,i_konto,i_kreddeb,
			i_kundenid,i_kunde_refid,i_lieferantid,i_lief_refid,i_steuerart_refid,i_verband,
			i_verbkto,si_bankeinzug,si_datevauto,si_klasse,si_mahnung,si_maxmahn,si_option1,
			si_option2,si_option3,si_skontierfaehig,si_ustpos,si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
	PROCEDURE delproc STATIC
	PARAMETERS
		STRING: ansprechpartner
		STRING: archiv
		STRING: creator
		STRING: email
		STRING: homepage
		STRING: kontoart
		STRING: konto_left
		STRING: kundennr
		STRING: landid
		STRING: manipulator
		STRING: name1
		STRING: name2
		STRING: name3
		STRING: ort
		STRING: ort2
		STRING: plz
		STRING: plz2
		STRING: schablone
		STRING: sprache
		STRING: steuernr
		STRING: strasse
		STRING: strasse2
		STRING: suche
		STRING: tel
		STRING: telefax
		STRING: text1
		STRING: text2
		STRING: text3
		STRING: titel
		STRING: unsnr
		STRING: ustidnr
		STRING: waehrung
		STRING: zahlziel
		STRING: zusatz
		NUMBER: wb_index
		NUMBER: wert1
		NUMBER: wert2
		NUMBER: wert3
		DATE/TIME: creation
		DATE/TIME: manipulation
		NUMBER: adressflags
		NUMBER: afakto
		NUMBER: anzahlkto
		NUMBER: clearing
		NUMBER: eigene_bank
		NUMBER: firm_refid
		NUMBER: fordkto
		NUMBER: kennung
		NUMBER: koartnr
		NUMBER: konto
		NUMBER: kreddeb
		NUMBER: kundenid
		NUMBER: kunde_refid
		NUMBER: lieferantid
		NUMBER: lief_refid
		NUMBER: steuerart_refid
		NUMBER: verband
		NUMBER: verbkto
		NUMBER: bankeinzug
		NUMBER: datevauto
		NUMBER: klasse
		NUMBER: mahnung
		NUMBER: maxmahn
		NUMBER: option1
		NUMBER: option2
		NUMBER: option3
		NUMBER: skontierfaehig
		NUMBER: ustpos
		NUMBER: verdichtet
		NUMBER: wawi_kennung
		NUMBER: gruppe_refid
		NUMBER: zessionstext
		NUMBER: az_fordkto
		NUMBER: az_verbkto
		NUMBER: zahlungsavis
		NUMBER: konto_datev
		NUMBER: ustid_pruef
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, \'D\', SYSDATETIME,
			:ansprechpartner, :archiv, :creator, :email, :homepage, :kontoart, :konto_left,
			:kundennr, :landid, :manipulator, :name1, :name2, :name3, :ort, :ort2, :plz, :plz2,
			:schablone, :sprache, :steuernr, :strasse, :strasse2, :suche, :tel, :telefax, :text1,
			:text2, :text3, :titel, :unsnr, :ustidnr, :waehrung, :zahlziel, :zusatz,
			:wb_index, :wert1, :wert2, :wert3,
			:creation, :manipulation, :adressflags, :afakto, :anzahlkto,
			:clearing, :eigene_bank, :firm_refid, :fordkto, :kennung, :koartnr, :konto, :kreddeb,
			:kundenid, :kunde_refid, :lieferantid, :lief_refid, :steuerart_refid, :verband,
			:verbkto, :bankeinzug, :datevauto, :klasse, :mahnung, :maxmahn, :option1,
			:option2, :option3, :skontierfaehig, :ustpos, :verdichtet,
			:wawi_kennung, :gruppe_refid, :zessionstext,
			:az_fordkto, :az_verbkto,
			:zahlungsavis, :konto_datev, :ustid_pruef)' )
	)
	FOR EACH ROW
	/

	CREATE TRIGGER fibu_ti_konto
	AFTER INSERT ON fibu_konto
	(EXECUTE INLINE(c_ansprechpartner,c_archiv,c_creator,c_email,c_homepage,c_kontoart,c_konto_left,
			c_kundennr,c_landid,c_manipulator,c_name,c_name2,c_name3,c_ort,c_ort2,c_plz,c_plz2,
			c_schablone,c_sprache,c_steuernr,c_strasse,c_strasse2,c_suche,c_tel,c_telefax,c_text1,
			c_text2,c_text3,c_titel,c_unsnr,c_ustidnr,c_waehrung,c_zahlziel,c_zusatz,
			dec_wb_index,dec_wert1,dec_wert2,dec_wert3,
			dt_creation,dt_manipulation,i_adressflags,i_afakto,i_anzahlkto,
			i_clearing,i_eigene_bank,i_firm_refid,i_fordkto,i_kennung,i_koartnr,i_konto,i_kreddeb,
			i_kundenid,i_kunde_refid,i_lieferantid,i_lief_refid,i_steuerart_refid,i_verband,
			i_verbkto,si_bankeinzug,si_datevauto,si_klasse,si_mahnung,si_maxmahn,si_option1,
			si_option2,si_option3,si_skontierfaehig,si_ustpos,si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
	PROCEDURE insproc STATIC
	PARAMETERS
		STRING: ansprechpartner
		STRING: archiv
		STRING: creator
		STRING: email
		STRING: homepage
		STRING: kontoart
		STRING: konto_left
		STRING: kundennr
		STRING: landid
		STRING: manipulator
		STRING: name1
		STRING: name2
		STRING: name3
		STRING: ort
		STRING: ort2
		STRING: plz
		STRING: plz2
		STRING: schablone
		STRING: sprache
		STRING: steuernr
		STRING: strasse
		STRING: strasse2
		STRING: suche
		STRING: tel
		STRING: telefax
		STRING: text1
		STRING: text2
		STRING: text3
		STRING: titel
		STRING: unsnr
		STRING: ustidnr
		STRING: waehrung
		STRING: zahlziel
		STRING: zusatz
		NUMBER: wb_index
		NUMBER: wert1
		NUMBER: wert2
		NUMBER: wert3
		DATE/TIME: creation
		DATE/TIME: manipulation
		NUMBER: adressflags
		NUMBER: afakto
		NUMBER: anzahlkto
		NUMBER: clearing
		NUMBER: eigene_bank
		NUMBER: firm_refid
		NUMBER: fordkto
		NUMBER: kennung
		NUMBER: koartnr
		NUMBER: konto
		NUMBER: kreddeb
		NUMBER: kundenid
		NUMBER: kunde_refid
		NUMBER: lieferantid
		NUMBER: lief_refid
		NUMBER: steuerart_refid
		NUMBER: verband
		NUMBER: verbkto
		NUMBER: bankeinzug
		NUMBER: datevauto
		NUMBER: klasse
		NUMBER: mahnung
		NUMBER: maxmahn
		NUMBER: option1
		NUMBER: option2
		NUMBER: option3
		NUMBER: skontierfaehig
		NUMBER: ustpos
		NUMBER: verdichtet
		NUMBER: wawi_kennung
		NUMBER: gruppe_refid
		NUMBER: zessionstext
		NUMBER: az_fordkto
		NUMBER: az_verbkto
		NUMBER:	zahlungsavis
		NUMBER: konto_datev
		NUMBER: ustid_pruef
	ACTIONS
		CALL SqlImmediate('INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, \'I\', SYSDATETIME,
			:ansprechpartner, :archiv, :creator, :email, :homepage, :kontoart, :konto_left,
			:kundennr, :landid, :manipulator, :name1, :name2, :name3, :ort, :ort2, :plz, :plz2,
			:schablone, :sprache, :steuernr, :strasse, :strasse2, :suche, :tel, :telefax, :text1,
			:text2, :text3, :titel, :unsnr, :ustidnr, :waehrung, :zahlziel, :zusatz,
			:wb_index, :wert1, :wert2, :wert3,
			:creation, :manipulation, :adressflags, :afakto, :anzahlkto,
			:clearing, :eigene_bank, :firm_refid, :fordkto, :kennung, :koartnr, :konto, :kreddeb,
			:kundenid, :kunde_refid, :lieferantid, :lief_refid, :steuerart_refid, :verband,
			:verbkto, :bankeinzug, :datevauto, :klasse, :mahnung, :maxmahn, :option1,
			:option2, :option3, :skontierfaehig, :ustpos, :verdichtet,
			:wawi_kennung, :gruppe_refid, :zessionstext,
			:az_fordkto, :az_verbkto,
			:zahlungsavis, :konto_datev, :ustid_pruef)' )
	)
	FOR EACH ROW
	/
#ELSE IF INFORMIX11
	#WHILE	SELECT trigname INTO :sInternalObjectName
		FROM informix.systriggers
		WHERE owner=USER AND trigname MATCHES 'fibu_t[iud]_konto'
			AND tabid=(SELECT tabid FROM informix.systables WHERE owner=USER AND tabname='fibu_konto')
	#LOOP
		DROP TRIGGER {InternalObjectName}
		/
	#ENDLOOP
	CREATE TRIGGER fibu_ti_konto
	INSERT ON fibu_konto
	REFERENCING NEW AS neu
	FOR EACH ROW (
		EXECUTE PROCEDURE fibuproc_ktoleft(neu.i_konto) INTO c_konto_left,
		INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, 'I', CURRENT,
			neu.c_ansprechpartner, neu.c_archiv, neu.c_creator, neu.c_email, neu.c_homepage, neu.c_kontoart, neu.c_konto_left,
			neu.c_kundennr, neu.c_landid, neu.c_manipulator, neu.c_name, neu.c_name2, neu.c_name3, neu.c_ort, neu.c_ort2, neu.c_plz, neu.c_plz2,
			neu.c_schablone, neu.c_sprache, neu.c_steuernr, neu.c_strasse, neu.c_strasse2, neu.c_suche, neu.c_tel, neu.c_telefax, neu.c_text1,
			neu.c_text2, neu.c_text3, neu.c_titel, neu.c_unsnr, neu.c_ustidnr, neu.c_waehrung, neu.c_zahlziel, neu.c_zusatz,
			neu.dec_wb_index, neu.dec_wert1, neu.dec_wert2, neu.dec_wert3,
			neu.dt_creation, neu.dt_manipulation, neu.i_adressflags, neu.i_afakto, neu.i_anzahlkto,
			neu.i_clearing, neu.i_eigene_bank, neu.i_firm_refid, neu.i_fordkto, neu.i_kennung, neu.i_koartnr, neu.i_konto, neu.i_kreddeb,
			neu.i_kundenid, neu.i_kunde_refid, neu.i_lieferantid, neu.i_lief_refid, neu.i_steuerart_refid, neu.i_verband,
			neu.i_verbkto, neu.si_bankeinzug, neu.si_datevauto, neu.si_klasse, neu.si_mahnung, neu.si_maxmahn, neu.si_option1,
			neu.si_option2, neu.si_option3, neu.si_skontierfaehig, neu.si_ustpos, neu.si_verdichtet,
			neu.si_wawi_kennung, neu.i_gruppe_refid, neu.i_zessionstext,
			neu.i_az_fordkto, neu.i_az_verbkto,
			neu.si_zahlungsavis, neu.i_konto_datev, neu.si_ustid_pruef)
		);
	/
	CREATE TRIGGER fibu_td_konto
	DELETE ON fibu_konto
	REFERENCING OLD AS alt
	FOR EACH ROW(
		INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, 'D', CURRENT,
			alt.c_ansprechpartner, alt.c_archiv, alt.c_creator, alt.c_email, alt.c_homepage, alt.c_kontoart, alt.c_konto_left,
			alt.c_kundennr, alt.c_landid, alt.c_manipulator, alt.c_name, alt.c_name2, alt.c_name3, alt.c_ort, alt.c_ort2, alt.c_plz, alt.c_plz2,
			alt.c_schablone, alt.c_sprache, alt.c_steuernr, alt.c_strasse, alt.c_strasse2, alt.c_suche, alt.c_tel, alt.c_telefax, alt.c_text1,
			alt.c_text2, alt.c_text3, alt.c_titel, alt.c_unsnr, alt.c_ustidnr, alt.c_waehrung, alt.c_zahlziel, alt.c_zusatz,
			alt.dec_wb_index, alt.dec_wert1, alt.dec_wert2, alt.dec_wert3,
			alt.dt_creation, alt.dt_manipulation, alt.i_adressflags, alt.i_afakto, alt.i_anzahlkto,
			alt.i_clearing, alt.i_eigene_bank, alt.i_firm_refid, alt.i_fordkto, alt.i_kennung, alt.i_koartnr, alt.i_konto, alt.i_kreddeb,
			alt.i_kundenid, alt.i_kunde_refid, alt.i_lieferantid, alt.i_lief_refid, alt.i_steuerart_refid, alt.i_verband,
			alt.i_verbkto, alt.si_bankeinzug, alt.si_datevauto, alt.si_klasse, alt.si_mahnung, alt.si_maxmahn, alt.si_option1,
			alt.si_option2, alt.si_option3, alt.si_skontierfaehig, alt.si_ustpos, alt.si_verdichtet,
			alt.si_wawi_kennung, alt.i_gruppe_refid, alt.i_zessionstext,
			alt.i_az_fordkto, alt.i_az_verbkto,
			alt.si_zahlungsavis, alt.i_konto_datev, alt.si_ustid_pruef)
		);
	/
	CREATE TRIGGER fibu_tu_konto
	UPDATE	OF	c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef
		ON fibu_konto
	REFERENCING OLD AS alt
	FOR EACH ROW(
		INSERT INTO fibu_pt_konto(c_pt_benutzer,c_pt_aktion,dt_pt_timestamp,
			c_ansprechpartner, c_archiv, c_creator, c_email, c_homepage, c_kontoart, c_konto_left,
			c_kundennr, c_landid, c_manipulator, c_name, c_name2, c_name3, c_ort, c_ort2, c_plz, c_plz2,
			c_schablone, c_sprache, c_steuernr, c_strasse, c_strasse2, c_suche, c_tel, c_telefax, c_text1,
			c_text2, c_text3, c_titel, c_unsnr, c_ustidnr, c_waehrung, c_zahlziel, c_zusatz,
			dec_wb_index, dec_wert1, dec_wert2, dec_wert3,
			dt_creation, dt_manipulation, i_adressflags, i_afakto, i_anzahlkto,
			i_clearing, i_eigene_bank, i_firm_refid, i_fordkto, i_kennung, i_koartnr, i_konto, i_kreddeb,
			i_kundenid, i_kunde_refid, i_lieferantid, i_lief_refid, i_steuerart_refid, i_verband,
			i_verbkto, si_bankeinzug, si_datevauto, si_klasse, si_mahnung, si_maxmahn, si_option1,
			si_option2, si_option3, si_skontierfaehig, si_ustpos, si_verdichtet,
			si_wawi_kennung, i_gruppe_refid, i_zessionstext,
			i_az_fordkto, i_az_verbkto,
			si_zahlungsavis, i_konto_datev, si_ustid_pruef)
		VALUES(USER, 'U', CURRENT,
			alt.c_ansprechpartner, alt.c_archiv, alt.c_creator, alt.c_email, alt.c_homepage, alt.c_kontoart, alt.c_konto_left,
			alt.c_kundennr, alt.c_landid, alt.c_manipulator, alt.c_name, alt.c_name2, alt.c_name3, alt.c_ort, alt.c_ort2, alt.c_plz, alt.c_plz2,
			alt.c_schablone, alt.c_sprache, alt.c_steuernr, alt.c_strasse, alt.c_strasse2, alt.c_suche, alt.c_tel, alt.c_telefax, alt.c_text1,
			alt.c_text2, alt.c_text3, alt.c_titel, alt.c_unsnr, alt.c_ustidnr, alt.c_waehrung, alt.c_zahlziel, alt.c_zusatz,
			alt.dec_wb_index, alt.dec_wert1, alt.dec_wert2, alt.dec_wert3,
			alt.dt_creation, alt.dt_manipulation, alt.i_adressflags, alt.i_afakto, alt.i_anzahlkto,
			alt.i_clearing, alt.i_eigene_bank, alt.i_firm_refid, alt.i_fordkto, alt.i_kennung, alt.i_koartnr, alt.i_konto, alt.i_kreddeb,
			alt.i_kundenid, alt.i_kunde_refid, alt.i_lieferantid, alt.i_lief_refid, alt.i_steuerart_refid, alt.i_verband,
			alt.i_verbkto, alt.si_bankeinzug, alt.si_datevauto, alt.si_klasse, alt.si_mahnung, alt.si_maxmahn, alt.si_option1,
			alt.si_option2, alt.si_option3, alt.si_skontierfaehig, alt.si_ustpos, alt.si_verdichtet,
			alt.si_wawi_kennung, alt.i_gruppe_refid, alt.i_zessionstext,
			alt.i_az_fordkto, alt.i_az_verbkto,
			alt.si_zahlungsavis, alt.i_konto_datev, alt.si_ustid_pruef)
		);
	/
#ENDIF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_steuerart
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[ud]_steuerart', 'fibu_steuerart' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_steuerart', 'fibu_steuerart', 'fibu_pt_steuerart', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_steuerart', 'fibu_steuerart', 'fibu_pt_steuerart', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_steuerklasse
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[ud]_steuklasse', 'fibu_steuerklasse' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_steuklasse', 'fibu_steuerklasse', 'fibu_pt_steuklasse', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_steuklasse', 'fibu_steuerklasse', 'fibu_pt_steuklasse', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_steuertabelle
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[ud]_steutabele', 'fibu_steuertabelle' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_steutabele', 'fibu_steuertabelle', 'fibu_pt_steutabele', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_steutabele', 'fibu_steuertabelle', 'fibu_pt_steutabele', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_systemdatum
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[ud]_systemdat', 'fibu_systemdatum' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_systemdat', 'fibu_systemdatum', 'fibu_pt_systemdat', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_systemdat', 'fibu_systemdatum', 'fibu_pt_systemdat', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_version
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[ud]_version', 'fibu_version' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_version', 'fibu_version', 'fibu_pt_version', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_version', 'fibu_version', 'fibu_pt_version', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_zahlziel
-----------------------------------------------------------------------------------------------------------------------------
#WHEN syska
	#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_zahlziel', 'fibu_zahlziel' )

	#SALCAE _ProtokollCreateTrigger( 'fibu_td_zahlziel', 'fibu_zahlziel', 'fibu_pt_zahlziel', 'D' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_tu_zahlziel', 'fibu_zahlziel', 'fibu_pt_zahlziel', 'U' )
#OFF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle op_einstellung
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_opeinstell', 'op_einstellung' )

#SALCAE _ProtokollCreateTrigger( 'fibu_td_opeinstell', 'op_einstellung', 'fibu_pt_opeinstell', 'D' )
#SALCAE _ProtokollCreateTrigger( 'fibu_tu_opeinstell', 'op_einstellung', 'fibu_pt_opeinstell', 'U' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_einstellung
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[pud]_fieinstell', 'fibu_einstellung' )

#SALCAE _ProtokollCreateTrigger( 'fibu_td_fieinstell', 'fibu_einstellung', 'fibu_pt_fieinstell', 'D' )
#SALCAE _ProtokollCreateTrigger( 'fibu_tu_fieinstell', 'fibu_einstellung', 'fibu_pt_fieinstell', 'U' )


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_menu_erteilt
-----------------------------------------------------------------------------------------------------------------------------
#WHEN syska
	#SALCAE _ProtokollDropTrigger( 'fibu_t[piud]_menu_erteilt', 'fibu_menu_erteilt' )

	#SALCAE _ProtokollCreateTrigger( 'fibu_td_menu_erteilt', 'fibu_menu_erteilt', 'fibu_pt_menu_erteilt', 'D' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_tu_menu_erteilt', 'fibu_menu_erteilt', 'fibu_pt_menu_erteilt', 'U' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_ti_menu_erteilt', 'fibu_menu_erteilt', 'fibu_pt_menu_erteilt', 'I' )
#OFF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_ben_gruppe
-----------------------------------------------------------------------------------------------------------------------------
#WHEN syska
	#SALCAE _ProtokollDropTrigger( 'fibu_t[iud]_ben_gruppe', 'fibu_ben_gruppe' )

	#SALCAE _ProtokollCreateTrigger( 'fibu_td_ben_gruppe', 'fibu_ben_gruppe', 'fibu_pt_ben_gruppe', 'D' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_tu_ben_gruppe', 'fibu_ben_gruppe', 'fibu_pt_ben_gruppe', 'U' )
	#SALCAE _ProtokollCreateTrigger( 'fibu_ti_ben_gruppe', 'fibu_ben_gruppe', 'fibu_pt_ben_gruppe', 'I' )
#OFF


-----------------------------------------------------------------------------------------------------------------------------
-- Tabelle fibu_konfiguration
-----------------------------------------------------------------------------------------------------------------------------
#SALCAE _ProtokollDropTrigger( 'fibu_t[puid]_konfig', 'fibu_konfiguration' )

#SALCAE _ProtokollCreateTrigger( 'fibu_tu_konfig', 'fibu_konfiguration', 'fibu_pt_konfig', 'U' )
#SALCAE _ProtokollCreateTrigger( 'fibu_td_konfig', 'fibu_konfiguration', 'fibu_pt_konfig', 'D' )


-----------------------------------------------------------------------------------------------------------------------------
-- Ende
-----------------------------------------------------------------------------------------------------------------------------
